==> 0.0.1.tar.gz: lib/src/custom_components/custom_autocomplete/view_model.dart <==
import 'package:flutter/material.dart';
import 'view.dart';

class OwlnextAutocomplete extends StatefulWidget {
  final TextEditingController controller;
  final void Function(String) onChange;
  final void Function(AutocompleteOption) onSelect;
  final List<AutocompleteOption> optionsList;
  final String? label;

  const OwlnextAutocomplete({
    required this.controller,
    required this.onChange,
    required this.optionsList,
    required this.onSelect,
    this.label,
    super.key 
  });

  @override
  OwlnextAutocompleteState createState() {
    return OwlnextAutocompleteState();
  }
}

class OwlnextAutocompleteState extends State<OwlnextAutocomplete> with ViewMixin {
  final OverlayPortalController portalController = OverlayPortalController();
  LayerLink link = LayerLink();
  FocusNode focus = FocusNode();
  double? inputWidth;
  bool isArrowDown = true;

  @override
  void initState() {
    super.initState();
    widget.controller.addListener(onFocusChange);
  }

  @override
  void dispose() {
    super.dispose();
    widget.controller.removeListener(onFocusChange);
  }
  
  void onFocusChange() async {
    setState(() {
      inputWidth = context.size?.width;  
    });

    if (focus.hasFocus == true && portalController.isShowing == false) {
      portalController.show();

      setState(() {
        isArrowDown = false;
      });
    } else if (focus.hasFocus == false) {
      handleClosePortal();
    }
  }

  void handleClosePortal() async {
    portalController.hide();
    setState(() {
      isArrowDown = true;
    });

    await Future.delayed(const Duration(milliseconds: 100));
    focus.unfocus();
  }

  void onSelect(AutocompleteOption selectedOption) {
    widget.onSelect(selectedOption);
    handleClosePortal();
  }

  @override
  Widget build(BuildContext context) {
    return render(context, this);
  }
}

class AutocompleteOption {
  final String label;
  final String value;

  AutocompleteOption({
    required this.label,
    required this.value,
  });
}

==> 0.0.4.tar.gz: lib/src/custom_components/custom_autocomplete/view_model.dart <==
import 'package:flutter/material.dart';
import 'view.dart';

class OwlnextAutocomplete extends StatefulWidget {
  /// Owlnext form input
  /// Based on Material design and uses [CompositedTransformTarget]
  /// Used to automate all autocompletes behaviors ine one place
  const OwlnextAutocomplete({
    required this.controller,
    required this.onChange,
    required this.optionsList,
    required this.onSelect,
    this.label,
    super.key 
  });

  /// Text input controller
  final TextEditingController controller;
  /// Callback on change text input controller
  final void Function(String) onChange;
  /// Callback on select option
  final void Function(AutocompleteOption) onSelect;
  /// Options List
  final List<AutocompleteOption> optionsList;
  /// Label above input
  final String? label;

  @override
  OwlnextAutocompleteState createState() {
    return OwlnextAutocompleteState();
  }
}

class OwlnextAutocompleteState extends State<OwlnextAutocomplete> with ViewMixin {
  final OverlayPortalController portalController = OverlayPortalController();
  LayerLink link = LayerLink();
  FocusNode focus = FocusNode();
  double? inputWidth;
  bool isArrowDown = true;

  @override
  void initState() {
    super.initState();
    focus.addListener(onFocusChange);
  }

  @override
  void dispose() {
    super.dispose();
    focus.removeListener(onFocusChange);
    focus.dispose();
  }
  
  void onFocusChange() async {
    setState(() {
      inputWidth = context.size?.width;  
    });

    if (focus.hasFocus == true && portalController.isShowing == false) {
      portalController.show();

      setState(() {
        isArrowDown = false;
      });
    } else if (focus.hasFocus == false && portalController.isShowing == true) {
      await Future.delayed(const Duration(milliseconds: 200));
      handleClosePortal();
    }
  }

  void handleClosePortal() async {
    portalController.hide();
    setState(() {
      isArrowDown = true;
    });

    await Future.delayed(const Duration(milliseconds: 100));
    focus.unfocus();
  }

  void onSelect(AutocompleteOption selectedOption) {
    widget.onSelect(selectedOption);
    handleClosePortal();
  }

  @override
  Widget build(BuildContext context) {
    return render(context, this);
  }
}

class AutocompleteOption {
  final Widget widget;
  final String value;

  AutocompleteOption({
    required this.widget,
    required this.value,
  });
}
